pub struct FmtResult {
pub changed: bool,
pub output: String,
}Expand description
Result of formatting a single file.
Indicates whether the file was already formatted or needed changes, and provides the formatted output when applicable.
Fields
changed: boolWhether the file content was changed by formatting.
output: StringThe formatted file content (identical to input if changed is false).
Implementations
Sourceimpl FmtResult
impl FmtResult
pub fn get_changed(&self) -> bool
pub fn get_mut_changed(&mut self) -> &mut bool
pub fn set_changed(&mut self, val: bool) -> &mut Self
pub fn get_output(&self) -> &String
pub fn get_mut_output(&mut self) -> &mut String
pub fn set_output(&mut self, val: String) -> &mut Self