pub struct ResponseMiddleware;Expand description
Response middleware that writes the serialized response to the stream.
Builds the HTTP response bytes and sends them through the connection stream, closing the stream if the send fails.
Implementations