Display

Trait Display 

1.0.0 · Source
pub trait Display {
    // Required method
    fn fmt(&self, f: &mut Formatter<'_>) -> Result<(), Error>;
}
Format trait for an empty format, {}.

Implementing this trait for a type will automatically implement the ToString trait for the type, allowing the usage of the .to_string() method. Prefer implementing the Display trait for a type, rather than ToString.

Display is similar to Debug, but Display is for user-facing output, and so cannot be derived.

For more information on formatters, see the module-level documentation.

Completeness and parseability

Display for a type might not necessarily be a lossless or complete representation of the type. It may omit internal state, precision, or other information the type does not consider important for user-facing output, as determined by the type. As such, the output of Display might not be possible to parse, and even if it is, the result of parsing might not exactly match the original value.

However, if a type has a lossless Display implementation whose output is meant to be conveniently machine-parseable and not just meant for human consumption, then the type may wish to accept the same format in FromStr, and document that usage. Having both Display and FromStr implementations where the result of Display cannot be parsed with FromStr may surprise users.

Internationalization

Because a type can only have one Display implementation, it is often preferable to only implement Display when there is a single most “obvious” way that values can be formatted as text. This could mean formatting according to the “invariant” culture and “undefined” locale, or it could mean that the type display is designed for a specific culture/locale, such as developer logs.

If not all values have a justifiably canonical textual format or if you want to support alternative formats not covered by the standard set of possible formatting traits, the most flexible approach is display adapters: methods like str::escape_default or Path::display which create a wrapper implementing Display to output the specific display format.

Examples

Implementing Display on a type:

use std::fmt;

struct Point {
    x: i32,
    y: i32,
}

impl fmt::Display for Point {
    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
        write!(f, "({}, {})", self.x, self.y)
    }
}

let origin = Point { x: 0, y: 0 };

assert_eq!(format!("The origin is: {origin}"), "The origin is: (0, 0)");

Required Methods

1.0.0 · Source

fn fmt(&self, f: &mut Formatter<'_>) -> Result<(), Error>

Formats the value using the given formatter.

Errors

This function should return Err if, and only if, the provided Formatter returns Err. String formatting is considered an infallible operation; this function only returns a Result because writing to the underlying stream might fail and it must provide a way to propagate the fact that an error has occurred back up the stack.

Examples
use std::fmt;

struct Position {
    longitude: f32,
    latitude: f32,
}

impl fmt::Display for Position {
    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
        write!(f, "({}, {})", self.longitude, self.latitude)
    }
}

assert_eq!(
    "(1.987, 2.983)",
    format!("{}", Position { longitude: 1.987, latitude: 2.983, }),
);

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

1.100.0 · Source

impl Display for !

1.26.0 · Source

impl Display for AccessError

Source

impl Display for AcquireError

1.4.0 · Source

impl Display for AddrParseError

Source

impl Display for AllocError

Source

impl Display for Arg

1.0.0 · Source

impl Display for Arguments<'_>

Source

impl Display for AsciiChar

Source

impl Display for Ast

Print a display representation of this Ast.

This does not preserve any of the original whitespace formatting that may have originally been present in the concrete syntax from which this Ast was generated.

This implementation uses constant stack space and heap space proportional to the size of the Ast.

Source

impl Display for http_type::attribute::enum::Attribute

Source

impl Display for icu_locale_core::extensions::unicode::attribute::Attribute

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.

Source

impl Display for xml::attribute::Attribute<'_>

Source

impl Display for Attributes

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.

Source

impl Display for BStr

Source

impl Display for BString

1.65.0 · Source

impl Display for Backtrace

Source

impl Display for BernoulliError

1.13.0 · Source

impl Display for BorrowError

1.13.0 · Source

impl Display for BorrowMutError

Source

impl Display for Buffer

Source

impl Display for regex_automata::dfa::onepass::BuildError

Source

impl Display for regex_automata::hybrid::error::BuildError

Source

impl Display for regex_automata::meta::error::BuildError

Source

impl Display for regex_automata::nfa::thompson::error::BuildError

Source

impl Display for aho_corasick::util::error::BuildError

Source

impl Display for ByteStr

Source

impl Display for ByteString

Source

impl Display for winnow::stream::bytes::Bytes

Source

impl Display for winnow::stream::bytes::Bytes

Source

impl Display for CacheError

Source

impl Display for CaseFoldError

1.34.0 · Source

impl Display for CharTryFromError

Source

impl Display for CollectionAllocErr

Source

impl Display for Color

Source

impl Display for ColorChoice

Source

impl Display for ColorType

Source

impl Display for Command

Source

impl Display for Compress

Implements the Display trait for the Compress enum.

This allows the Compress enum variants to be formatted as strings, typically used for outputting the Content-Encoding header value.

Source

impl Display for CompressError

Source

impl Display for Context

Source

impl Display for ContextError

Source

impl Display for ContextKind

Source

impl Display for ContextValue

Source

impl Display for CurrencyType

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.

Source

impl Display for DataError

Source

impl Display for DataErrorKind

Source

impl Display for DataIdentifierBorrowed<'_>

Source

impl Display for DataLocale

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.

Source

impl Display for Date

Source

impl Display for Datetime

Available on crate feature alloc only.
Source

impl Display for DatetimeParseError

Source

impl Display for DeFloat<'_>

Source

impl Display for DeInteger<'_>

1.9.0 · Source

impl Display for DecodeUtf16Error

Source

impl Display for flate2::mem::DecompressError

Source

impl Display for miniz_oxide::inflate::DecompressError

Available on crate feature with-alloc only.
Source

impl Display for DefaultServerHook

Source

impl Display for DeserializeError

1.87.0 · Source

impl Display for std::ffi::os_str::Display<'_>

1.0.0 · Source

impl Display for std::path::Display<'_>

Source

impl Display for Elapsed

Source

impl Display for EmitterError

Source

impl Display for Empty

Source

impl Display for EmptyError

Source

impl Display for Encoding

Source

impl Display for Errno

1.0.0 · Source

impl Display for euv_cli::IoError

1.0.0 · Source

impl Display for core::fmt::Error

Source

impl Display for rand::distr::uniform::Error

Source

impl Display for rand::distr::weighted::Error

Source

impl Display for getrandom::error::Error

Source

impl Display for serde_json::error::Error

Source

impl Display for serde_core::de::value::Error

Source

impl Display for tokio::time::error::Error

Source

impl Display for icu_collections::codepointtrie::error::Error

Source

impl Display for serde_xml_rs::error::Error

Source

impl Display for xml::reader::error::Error

Source

impl Display for serde_urlencoded::ser::Error

Source

impl Display for regex::error::Error

Source

impl Display for regex_syntax::ast::Error

Source

impl Display for regex_syntax::error::Error

Source

impl Display for regex_syntax::hir::Error

Source

impl Display for ignore::Error

Source

impl Display for globset::Error

Source

impl Display for walkdir::error::Error

Source

impl Display for notify::error::Error

Source

impl Display for toml::de::error::Error

Displays a TOML parse error

Example

TOML parse error at line 1, column 10 | 1 | 00:32:00.a999999 | ^ Unexpected a Expected digit While parsing a Time While parsing a Date-Time

Source

impl Display for toml::ser::error::Error

Source

impl Display for which::error::Error

1.60.0 · Source

impl Display for core::io::error::ErrorKind

Source

impl Display for clap_builder::error::kind::ErrorKind

Source

impl Display for regex_syntax::ast::ErrorKind

Source

impl Display for regex_syntax::hir::ErrorKind

Source

impl Display for globset::ErrorKind

Source

impl Display for Errors

1.20.0 · Source

impl Display for core::char::EscapeDebug

1.39.0 · Source

impl Display for core::ascii::EscapeDefault

1.16.0 · Source

impl Display for core::char::EscapeDefault

1.16.0 · Source

impl Display for core::char::EscapeUnicode

Source

impl Display for EuvError

Implements Display for EuvError to provide human-readable error messages.

Source

impl Display for EventMaskParseError

1.0.0 · Source

impl Display for ExitStatus

Source

impl Display for ExitStatusError

Source

impl Display for Extensions

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.

Source

impl Display for Fields

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.

Source

impl Display for FileExtension

1.69.0 · Source

impl Display for FromBytesUntilNulError

1.17.0 · Source

impl Display for FromBytesWithNulError

Source

impl Display for FromHexError

1.0.0 · Source

impl Display for euv_cli::FromUtf8Error

Source

impl Display for bstr::ext_vec::FromUtf8Error

1.0.0 · Source

impl Display for FromUtf16Error

1.58.0 · Source

impl Display for FromVecWithNulError

1.86.0 · Source

impl Display for GetDisjointMutError

Source

impl Display for Glob

Source

impl Display for GroupInfoError

Source

impl Display for Hir

Print a display representation of this Hir.

The result of this is a valid regular expression pattern string.

This implementation uses constant stack space and heap space proportional to the size of the Hir.

Source

impl Display for Hook

Source

impl Display for HookType

Source

impl Display for HttpStatus

Implements the Display trait for HttpStatus, allowing it to be formatted as a string.

Source

impl Display for HttpUrlError

Implements the Display trait for HttpUrlError, allowing it to be formatted as a string.

Source

impl Display for HttpVersion

Implements the Display trait for HttpVersion, allowing it to be formatted as a string.

Source

impl Display for clap_builder::util::id::Id

Source

impl Display for tokio::runtime::task::id::Id

Source

impl Display for tokio::runtime::id::Id

Source

impl Display for ImmutableEntitiesError

Source

impl Display for InternalAttribute

1.7.0 · Source

impl Display for IntoStringError

Source

impl Display for InvalidSetError

Source

impl Display for InvalidStringList

1.7.0 · Source

impl Display for IpAddr

1.0.0 · Source

impl Display for Ipv4Addr

1.0.0 · Source

impl Display for Ipv6Addr

Writes an Ipv6Addr, conforming to the canonical style described by RFC 5952.

Source

impl Display for JoinError

1.0.0 · Source

impl Display for JoinPathsError

Source

impl Display for icu_locale_core::extensions::transform::key::Key

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.

Source

impl Display for icu_locale_core::extensions::unicode::key::Key

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.

Source

impl Display for Keywords

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.

Source

impl Display for Language

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.

Source

impl Display for LanguageIdentifier

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.

1.28.0 · Source

impl Display for LayoutError

Source

impl Display for Level

Source

impl Display for LevelFilter

Source

impl Display for Locale

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.

1.26.0 · Source

impl Display for Location<'_>

Source

impl Display for Map<String, Value>

Available on crate feature display only.
Source

impl Display for regex_automata::util::search::MatchError

Source

impl Display for aho_corasick::util::error::MatchError

Source

impl Display for MatchesError

Source

impl Display for Method

Implements the Display trait for Method, allowing it to be formatted as a string.

Source

impl Display for Name<'_>

Source

impl Display for NewError

Source

impl Display for NonFatalError

Source

impl Display for NormalizeError

1.0.0 · Source

impl Display for NulError

Source

impl Display for Number

Source

impl Display for Offset

Source

impl Display for OneshotWithSecretError

Source

impl Display for Other

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.

Source

impl Display for OwnedAttribute

Source

impl Display for OwnedName

Source

impl Display for PanicData

1.26.0 · Source

impl Display for PanicHookInfo<'_>

1.26.0 · Source

impl Display for PanicInfo<'_>

1.81.0 · Source

impl Display for PanicMessage<'_>

1.0.0 · Source

impl Display for ParseBoolError

1.20.0 · Source

impl Display for ParseCharError

Source

impl Display for url::parser::ParseError

Source

impl Display for icu_locale_core::parser::errors::ParseError

Source

impl Display for tinystr::error::ParseError

Source

impl Display for bitflags::parser::ParseError

1.0.0 · Source

impl Display for ParseFloatError

1.0.0 · Source

impl Display for ParseIntError

Source

impl Display for ParseLevelError

Source

impl Display for regex_automata::util::primitives::PatternIDError

Source

impl Display for aho_corasick::util::primitives::PatternIDError

Source

impl Display for PatternSetInsertError

Available on crate feature alloc only.
Source

impl Display for PercentEncode<'_>

Source

impl Display for PreferencesParseError

Source

impl Display for Private

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.

Source

impl Display for PublishError

Source

impl Display for QrError

Source

impl Display for winnow::stream::range::Range

Source

impl Display for winnow::stream::range::Range

Source

impl Display for RangeError

1.0.0 · Source

impl Display for std::sync::mpsc::RecvError

Source

impl Display for tokio::sync::broadcast::error::RecvError

Source

impl Display for tokio::sync::oneshot::error::RecvError

Source

impl Display for tokio::sync::watch::error::RecvError

1.15.0 · Source

impl Display for std::sync::mpsc::RecvTimeoutError

Source

impl Display for regex::regex::bytes::Regex

Source

impl Display for regex::regex::string::Regex

Source

impl Display for Region

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.

Source

impl Display for Request

Source

impl Display for RequestConfig

Source

impl Display for RequestError

Source

impl Display for Reset

Source

impl Display for Response

Source

impl Display for ResponseError

Implements the Display trait for ResponseError. This allows ResponseError variants to be formatted into human-readable strings.

Source

impl Display for tokio::net::tcp::split_owned::ReuniteError

Source

impl Display for tokio::net::unix::split_owned::ReuniteError

Source

impl Display for RouteError

Source

impl Display for RouteMatcher

Source

impl Display for RoutePattern

Source

impl Display for RouteSegment

Source

impl Display for Script

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.

Source

impl Display for SerializeError

Source

impl Display for SerializerError

Source

impl Display for Server

Source

impl Display for ServerConfig

Source

impl Display for ServerControlHook

Source

impl Display for ServerError

Source

impl Display for SetLoggerError

Source

impl Display for SmallIndexError

1.0.0 · Source

impl Display for SocketAddr

1.0.0 · Source

impl Display for SocketAddrV4

1.0.0 · Source

impl Display for SocketAddrV6

Source

impl Display for StartError

Source

impl Display for regex_automata::util::primitives::StateIDError

Source

impl Display for aho_corasick::util::primitives::StateIDError

Source

impl Display for Str

Source

impl Display for StrContext

Source

impl Display for StrContextValue

Source

impl Display for StrSimError

Source

impl Display for Stream

1.0.0 · Source

impl Display for String

1.7.0 · Source

impl Display for StripPrefixError

Source

impl Display for StrippedStr<'_>

Source

impl Display for Style

Source

impl Display for StyledStr

Color-unaware printing. Never uses coloring.

Source

impl Display for SubdivisionId

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.

Source

impl Display for SubdivisionSuffix

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.

Source

impl Display for icu_locale_core::extensions::private::other::Subtag

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.

Source

impl Display for icu_locale_core::subtags::Subtag

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.

Source

impl Display for SyntaxViolation

1.8.0 · Source

impl Display for SystemTimeError

Source

impl Display for Task

Source

impl Display for TemplateError

Source

impl Display for TextPosition

Source

impl Display for Time

Available on crate feature alloc only.
Source

impl Display for ToCasefold

1.16.0 · Source

impl Display for ToLowercase

Source

impl Display for ToTitlecase

1.16.0 · Source

impl Display for ToUppercase

Source

impl Display for Transform

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.

Source

impl Display for TryAcquireError

Source

impl Display for TryCurrentError

1.59.0 · Source

impl Display for TryFromCharError

1.66.0 · Source

impl Display for TryFromFloatSecsError

1.34.0 · Source

impl Display for TryFromIntError

1.35.0 · Source

impl Display for TryFromSliceError

Source

impl Display for TryGetError

1.89.0 · Source

impl Display for std::fs::TryLockError

Source

impl Display for tokio::sync::mutex::TryLockError

1.0.0 · Source

impl Display for std::sync::mpsc::TryRecvError

Source

impl Display for tokio::sync::broadcast::error::TryRecvError

Source

impl Display for tokio::sync::mpsc::error::TryRecvError

Source

impl Display for tokio::sync::oneshot::error::TryRecvError

1.57.0 · Source

impl Display for TryReserveError

Source

impl Display for UleError

Source

impl Display for Unicode

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.

Source

impl Display for UnicodeWordBoundaryError

Source

impl Display for UnicodeWordError

Source

impl Display for UnorderedKeyError

Source

impl Display for UpgradeType

Implements the Display trait for UpgradeType. This allows UpgradeType variants to be formatted into human-readable strings.

Source

impl Display for Url

Display the serialization of this URL.

Source

impl Display for Utf8CharsError

1.0.0 · Source

impl Display for core::str::error::Utf8Error

Source

impl Display for bstr::utf8::Utf8Error

Source

impl Display for serde_json::value::Value

Source

impl Display for icu_locale_core::extensions::transform::value::Value

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.

Source

impl Display for icu_locale_core::extensions::unicode::value::Value

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.

Source

impl Display for toml::value::Value

Available on crate feature display only.
Source

impl Display for ValueRange

1.0.0 · Source

impl Display for VarError

Source

impl Display for Variant

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.

Source

impl Display for Variants

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.

Source

impl Display for WebSocketFrame

Source

impl Display for WouldBlock

1.56.0 · Source

impl Display for WriterPanicked

Source

impl Display for XmlVersion

Source

impl Display for ZeroTrieBuildError

1.0.0 · Source

impl Display for bool

1.0.0 · Source

impl Display for char

Source

impl Display for dyn Expected + '_

1.0.0 · Source

impl Display for f16

1.0.0 · Source

impl Display for f32

1.0.0 · Source

impl Display for f64

1.0.0 · Source

impl Display for i8

1.0.0 · Source

impl Display for i16

1.0.0 · Source

impl Display for i32

1.0.0 · Source

impl Display for i64

1.0.0 · Source

impl Display for i128

1.0.0 · Source

impl Display for isize

1.0.0 · Source

impl Display for str

1.0.0 · Source

impl Display for u8

1.0.0 · Source

impl Display for u16

1.0.0 · Source

impl Display for u32

1.0.0 · Source

impl Display for u64

1.0.0 · Source

impl Display for u128

1.0.0 · Source

impl Display for usize

Source

impl<'a, 'b> Display for ReprDisplay<'a, 'b>
where 'b: 'a,

Source

impl<'a, A, C> Display for Replace<A, &'a str, C>
where A: Writeable, C: Writeable,

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.

Source

impl<'a, R, G, T> Display for MappedReentrantMutexGuard<'a, R, G, T>
where R: RawMutex + 'a, G: GetThreadId + 'a, T: Display + 'a + ?Sized,

Source

impl<'a, R, G, T> Display for ReentrantMutexGuard<'a, R, G, T>
where R: RawMutex + 'a, G: GetThreadId + 'a, T: Display + 'a + ?Sized,

Source

impl<'a, R, T> Display for lock_api::mutex::MappedMutexGuard<'a, R, T>
where R: RawMutex + 'a, T: Display + 'a + ?Sized,

Source

impl<'a, R, T> Display for lock_api::rwlock::MappedRwLockReadGuard<'a, R, T>
where R: RawRwLock + 'a, T: Display + 'a + ?Sized,

Source

impl<'a, R, T> Display for lock_api::rwlock::MappedRwLockWriteGuard<'a, R, T>
where R: RawRwLock + 'a, T: Display + 'a + ?Sized,

Source

impl<'a, R, T> Display for lock_api::mutex::MutexGuard<'a, R, T>
where R: RawMutex + 'a, T: Display + 'a + ?Sized,

Source

impl<'a, R, T> Display for lock_api::rwlock::RwLockReadGuard<'a, R, T>
where R: RawRwLock + 'a, T: Display + 'a + ?Sized,

Source

impl<'a, R, T> Display for RwLockUpgradableReadGuard<'a, R, T>
where R: RawRwLockUpgrade + 'a, T: Display + 'a + ?Sized,

Source

impl<'a, R, T> Display for lock_api::rwlock::RwLockWriteGuard<'a, R, T>
where R: RawRwLock + 'a, T: Display + 'a + ?Sized,

Source

impl<'a, T> Display for tokio::sync::mutex::MappedMutexGuard<'a, T>
where T: Display + ?Sized,

Source

impl<'a, T> Display for RwLockMappedWriteGuard<'a, T>
where T: Display + ?Sized,

Source

impl<'a, T> Display for tokio::sync::rwlock::read_guard::RwLockReadGuard<'a, T>
where T: Display + ?Sized,

Source

impl<'a, T> Display for tokio::sync::rwlock::write_guard::RwLockWriteGuard<'a, T>
where T: Display + ?Sized,

1.60.0 · Source

impl<'a> Display for EscapeAscii<'a>

Source

impl<'a> Display for EscapeBytes<'a>

1.34.0 · Source

impl<'a> Display for core::str::iter::EscapeDebug<'a>

1.34.0 · Source

impl<'a> Display for core::str::iter::EscapeDefault<'a>

1.34.0 · Source

impl<'a> Display for core::str::iter::EscapeUnicode<'a>

Source

impl<'a> Display for Unexpected<'a>

Source

impl<A, B> Display for Concat<A, B>
where A: Writeable, B: Writeable,

1.0.0 · Source

impl<B> Display for Cow<'_, B>
where B: Display + ToOwned + ?Sized, <B as ToOwned>::Owned: Display,

Source

impl<E> Display for ErrMode<E>
where E: Debug,

Source

impl<E> Display for Report<E>
where E: Error,

Source

impl<F> Display for clap_builder::error::Error<F>
where F: ErrorFormatter,

1.93.0 · Source

impl<F> Display for FromFn<F>
where F: Fn(&mut Formatter<'_>) -> Result<(), Error>,

Source

impl<I, E> Display for winnow::error::ParseError<I, E>
where I: AsBStr, E: Display,

Source

impl<I, S> Display for winnow::stream::stateful::Stateful<I, S>
where I: Display,

Source

impl<I, S> Display for winnow::stream::stateful::Stateful<I, S>
where I: Display,

Source

impl<I> Display for InputError<I>
where I: Clone + Display,

The Display implementation allows the std::error::Error implementation

Source

impl<I> Display for winnow::stream::locating::LocatingSlice<I>
where I: Display,

Source

impl<I> Display for winnow::stream::locating::LocatingSlice<I>
where I: Display,

Source

impl<I> Display for winnow::stream::partial::Partial<I>
where I: Display,

Source

impl<I> Display for winnow::stream::partial::Partial<I>
where I: Display,

1.33.0 · Source

impl<Ptr> Display for Pin<Ptr>
where Ptr: Display,

Source

impl<S> Display for Host<S>
where S: AsRef<str>,

Source

impl<S> Display for SecretTooShortError<S>

Source

impl<S> Display for SecretWithSeedError<S>

1.0.0 · Source

impl<T, A> Display for Arc<T, A>
where T: Display + ?Sized, A: Allocator,

1.0.0 · Source

impl<T, A> Display for Box<T, A>
where T: Display + ?Sized, A: Allocator,

1.0.0 · Source

impl<T, A> Display for Rc<T, A>
where T: Display + ?Sized, A: Allocator,

Source

impl<T, A> Display for UniqueArc<T, A>
where T: Display + ?Sized, A: Allocator,

Source

impl<T, A> Display for UniqueRc<T, A>
where T: Display + ?Sized, A: Allocator,

Source

impl<T, U> Display for OwnedMappedMutexGuard<T, U>
where U: Display + ?Sized, T: ?Sized,

Source

impl<T, U> Display for OwnedRwLockMappedWriteGuard<T, U>
where U: Display + ?Sized, T: ?Sized,

Source

impl<T, U> Display for OwnedRwLockReadGuard<T, U>
where U: Display + ?Sized, T: ?Sized,

1.0.0 · Source

impl<T> Display for &T
where T: Display + ?Sized,

1.0.0 · Source

impl<T> Display for &mut T
where T: Display + ?Sized,

Source

impl<T> Display for AsyncFdTryNewError<T>

Source

impl<T> Display for CachePadded<T>
where T: Display,

Source

impl<T> Display for LossyWrap<T>
where T: TryWriteable,

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.

Source

impl<T> Display for std::sync::nonpoison::mutex::MappedMutexGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for std::sync::poison::mutex::MappedMutexGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for std::sync::nonpoison::rwlock::MappedRwLockReadGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for std::sync::poison::rwlock::MappedRwLockReadGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for std::sync::nonpoison::rwlock::MappedRwLockWriteGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for std::sync::poison::rwlock::MappedRwLockWriteGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for std::sync::nonpoison::mutex::MutexGuard<'_, T>
where T: Display + ?Sized,

1.20.0 · Source

impl<T> Display for std::sync::poison::mutex::MutexGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for tokio::sync::mutex::MutexGuard<'_, T>
where T: Display + ?Sized,

1.28.0 · Source

impl<T> Display for NonZero<T>

Source

impl<T> Display for OwnedMutexGuard<T>
where T: Display + ?Sized,

Source

impl<T> Display for OwnedRwLockWriteGuard<T>
where T: Display + ?Sized,

1.0.0 · Source

impl<T> Display for PoisonError<T>

Source

impl<T> Display for std::sync::oneshot::RecvTimeoutError<T>

Source

impl<T> Display for ReentrantLockGuard<'_, T>
where T: Display + ?Sized,

1.20.0 · Source

impl<T> Display for Ref<'_, T>
where T: Display + ?Sized,

1.20.0 · Source

impl<T> Display for RefMut<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for std::sync::nonpoison::rwlock::RwLockReadGuard<'_, T>
where T: Display + ?Sized,

1.20.0 · Source

impl<T> Display for std::sync::poison::rwlock::RwLockReadGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for std::sync::nonpoison::rwlock::RwLockWriteGuard<'_, T>
where T: Display + ?Sized,

1.20.0 · Source

impl<T> Display for std::sync::poison::rwlock::RwLockWriteGuard<'_, T>
where T: Display + ?Sized,

1.74.0 · Source

impl<T> Display for Saturating<T>
where T: Display,

1.0.0 · Source

impl<T> Display for std::sync::mpsc::SendError<T>

Source

impl<T> Display for tokio::sync::broadcast::error::SendError<T>

Source

impl<T> Display for tokio::sync::mpsc::error::SendError<T>

Source

impl<T> Display for tokio::sync::watch::error::SendError<T>

Source

impl<T> Display for std::sync::mpmc::error::SendTimeoutError<T>

Source

impl<T> Display for tokio::sync::mpsc::error::SendTimeoutError<T>

Available on crate feature time only.
Source

impl<T> Display for SetError<T>

Source

impl<T> Display for SetOnceError<T>

Source

impl<T> Display for ShardedLockReadGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for ShardedLockWriteGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for Spanned<T>
where T: Display,

Source

impl<T> Display for ThinBox<T>
where T: Display + ?Sized,

1.0.0 · Source

impl<T> Display for std::sync::poison::TryLockError<T>

Source

impl<T> Display for std::sync::oneshot::TryRecvError<T>

1.0.0 · Source

impl<T> Display for std::sync::mpsc::TrySendError<T>

Source

impl<T> Display for tokio::sync::mpsc::error::TrySendError<T>

Source

impl<T> Display for TryWriteableInfallibleAsWriteable<T>
where T: TryWriteable<Error = !>,

Source

impl<T> Display for WithPart<T>
where T: Writeable + ?Sized,

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.

1.10.0 · Source

impl<T> Display for Wrapping<T>
where T: Display,

1.0.0 · Source

impl<W> Display for IntoInnerError<W>

Source

impl<Y, C> Display for Yoke<Y, C>
where Y: for<'a> Yokeable<'a>, <Y as Yokeable<'a>>::Output: for<'a> Display,

Source

impl<const N: usize> Display for TinyAsciiStr<N>